@@ -104,6 +104,10 @@ typedef struct DistributeObjectOps
 
 const DistributeObjectOps * GetDistributeObjectOps(Node *node);
 
+/* functions to support node-wide object management commands from non-main dbs */
+extern bool RunPreprocessNonMainDBCommand(Node *parsetree);
+extern void RunPostprocessNonMainDBCommand(Node *parsetree);
+
 /*
  * Flags that can be passed to GetForeignKeyOids to indicate
  * which foreign key constraint OIDs are to be extracted
@@ -230,6 +234,28 @@ extern List * PreprocessAlterDatabaseStmt(Node *node, const char *queryString,
 extern List * PreprocessAlterDatabaseRefreshCollStmt(Node *node, const char *queryString,
 													 ProcessUtilityContext
 													 processUtilityContext);
+extern List * GetDatabaseMetadataSyncCommands(Oid dbOid);
+
+
+extern List * PreprocessAlterDatabaseSetStmt(Node *node, const char *queryString,
+											 ProcessUtilityContext processUtilityContext);
+
+extern List * PreprocessCreateDatabaseStmt(Node *node, const char *queryString,
+										   ProcessUtilityContext processUtilityContext);
+extern List * PostprocessCreateDatabaseStmt(Node *node, const char *queryString);
+extern List * PreprocessDropDatabaseStmt(Node *node, const char *queryString,
+										 ProcessUtilityContext processUtilityContext);
+extern List * DropDatabaseStmtObjectAddress(Node *node, bool missingOk,
+											bool isPostprocess);
+extern List * CreateDatabaseStmtObjectAddress(Node *node, bool missingOk,
+											  bool isPostprocess);
+extern List * GenerateGrantDatabaseCommandList(void);
+extern List * PreprocessAlterDatabaseRenameStmt(Node *node, const char *queryString,
+												ProcessUtilityContext
+												processUtilityContext);
+extern List * PostprocessAlterDatabaseRenameStmt(Node *node, const char *queryString);
+extern void EnsureSupportedCreateDatabaseCommand(CreatedbStmt *stmt);
+extern char * CreateDatabaseDDLCommand(Oid dbId);
 
 
 /* domain.c - forward declarations */
@@ -424,6 +450,7 @@ extern List * CreateExtensionStmtObjectAddress(Node *stmt, bool missing_ok, bool
 /* owned.c -  forward declarations */
 extern List * PreprocessDropOwnedStmt(Node *node, const char *queryString,
 									  ProcessUtilityContext processUtilityContext);
+extern List * PostprocessReassignOwnedStmt(Node *node, const char *queryString);
 
 /* policy.c -  forward declarations */
 extern List * CreatePolicyCommands(Oid relationId);
@@ -476,6 +503,10 @@ extern List * PreprocessRenameAttributeStmt(Node *stmt, const char *queryString,
 extern List * PostprocessAlterRoleStmt(Node *stmt, const char *queryString);
 extern List * PreprocessAlterRoleSetStmt(Node *stmt, const char *queryString,
 										 ProcessUtilityContext processUtilityContext);
+
+extern List * PreprocessAlterRoleRenameStmt(Node *stmt, const char *queryString,
+											ProcessUtilityContext processUtilityContext);
+
 extern List * GenerateAlterRoleSetCommandForRole(Oid roleid);
 extern List * AlterRoleStmtObjectAddress(Node *node,
 										 bool missing_ok, bool isPostprocess);
@@ -491,6 +522,10 @@ extern List * PostprocessGrantRoleStmt(Node *stmt, const char *queryString);
 extern List * GenerateCreateOrAlterRoleCommand(Oid roleOid);
 extern List * CreateRoleStmtObjectAddress(Node *stmt, bool missing_ok, bool
 										  isPostprocess);
+
+extern List * RenameRoleStmtObjectAddress(Node *stmt, bool missing_ok, bool
+										  isPostprocess);
+
 extern void UnmarkRolesDistributed(List *roles);
 extern List * FilterDistributedRoles(List *roles);
 
@@ -511,7 +546,9 @@ extern List * AlterSchemaRenameStmtObjectAddress(Node *node, bool missing_ok, bo
 												 isPostprocess);
 
 /* seclabel.c - forward declarations*/
-extern List * PostprocessSecLabelStmt(Node *node, const char *queryString);
+extern List * PostprocessAnySecLabelStmt(Node *node, const char *queryString);
+extern List * PostprocessRoleSecLabelStmt(Node *node, const char *queryString);
+extern List * PostprocessTableOrColumnSecLabelStmt(Node *node, const char *queryString);
 extern List * SecLabelStmtObjectAddress(Node *node, bool missing_ok, bool isPostprocess);
 extern void citus_test_object_relabel(const ObjectAddress *object, const char *seclabel);
 
@@ -659,11 +696,6 @@ extern List * AlterTextSearchConfigurationSchemaStmtObjectAddress(Node *node,
 extern List * AlterTextSearchDictionarySchemaStmtObjectAddress(Node *node,
 															   bool missing_ok, bool
 															   isPostprocess);
-extern List * TextSearchConfigurationCommentObjectAddress(Node *node,
-														  bool missing_ok, bool
-														  isPostprocess);
-extern List * TextSearchDictCommentObjectAddress(Node *node,
-												 bool missing_ok, bool isPostprocess);
 extern List * AlterTextSearchConfigurationOwnerObjectAddress(Node *node,
 															 bool missing_ok, bool
 															 isPostprocess);
